/*
** Module   : ComboBoxWidget.java
** Abstract : server side combo box widget implementation
**
** Copyright (c) 2005-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------Description-----------------
** 001 NVS 20051026   @23483 Created initial version.
** 002 SIY 20050209   @24433 Major refactoring.
** 003 SIY 20050209   @24494 Added missing setInnerLines method.
** 004 GES 20060803   @28368 Some cleanup and refactoring.
** 005 GES 20080320   @37583 Added TYPE attribute.
** 006 SIY 20111101          Updated imports.
** 007 CA  20130221          Refactored usage of TYPE attribute.
*/ 

package com.goldencode.p2j.ui;

import com.goldencode.p2j.util.*;

/**
 * Server side combo box widget implementation.
 */
public class ComboBoxWidget
extends ControlSetEntity
{
   /** Reference to our configuration which is pre-cast to the proper type. */
   private ComboBoxConfig cbc = null;
   
   /**
    * Default constructor.
    */
   public ComboBoxWidget()
   {
      super(new ComboBoxConfig(ComponentConfig.COMBO_BOX, null));
      cbc = (ComboBoxConfig) config;
      
      setResourceType("COMBO-BOX");
   }
   
   /**
    * Set DROP-DOWN-LIST mode for the widget. Has no effect in character mode
    * interface.
    * 
    * @param   b
    *          <code>true</code> enables mode, <code>false</code> is
    *          ignored.
    */
   public void setModeDropDownList(boolean b)
   {
      // do nothing
   }

   /**
    * Set DROP-DOWN mode for the widget. Has no effect in character mode
    * interface.
    * 
    * @param   b
    *          <code>true</code> enables mode, <code>false</code> is
    *          ignored.
    */
   public void setModeDropDown(boolean b)
   {
      // do nothing
   }
   
   /**
    * Set SIMPLE mode for the widget. Has no effect in character mode
    * interface.
    * 
    * @param   b
    *          <code>true</code> enables mode, <code>false</code> is
    *          ignored.
    */
   public void setModeSimple(boolean b)
   {
      // do nothing
   }

   /**
    * Set number of inner lines in the widget drop-down window.
    * 
    * @param   lines
    */
   public void setInnerLines(int lines)
   {
      cbc.setInnerLines(lines);
      frame.pushScreenDefinition();
   }
}
