/*
** Module   : FillInWidget.java
** Abstract : server side FillIn widget implementation
**
** Copyright (c) 2005-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------Description----------------------
** 001 NVS 20051026   @23490 Created initial version.
** 002 GES 20060114   @23909 Removed totally useless screen-value attr.
** 003 SIY 20060404   @25357 Support for the text group.
** 004 GES 20060803   @28375 Cleanup and refactoring.
** 005 GES 20080320   @37590 Added TYPE attribute.
** 006 SVL 20101006          Added NATIVE attribute.
** 007 SIY 20111101          Updated imports.
** 008 CA  20130221          Refactored usage of TYPE attribute.
*/ 

package com.goldencode.p2j.ui;

import com.goldencode.p2j.util.*;

/**
 * Server side FillIn widget implementation.
 */
public class FillInWidget
extends ControlTextWidget
{
   /** Reference to our configuration which is pre-cast to the proper type. */
   private FillInConfig fic = null;
   
   /**
    * Default constructor.
    */
   public FillInWidget()
   {
      super(new FillInConfig(ComponentConfig.FILL_IN, null));
      fic = (FillInConfig) config;
      
      setResourceType("FILL-IN");
   }

   /**
    * Sets a read only state.
    * 
    * @param   newReadOnly
    *          Is widget read only.
    */
   public void setReadOnly(boolean newReadOnly)
   {
      fic.setReadOnly(newReadOnly);
   }

   /**
    * Start text group of widgets (word wrap mode).
    * 
    * @param   prev
    *          Reference to previous fill-in widget or null if no such
    *          widgets.
    */
   public void startGrouping(FillInWidget prev)
   {
      fic.setTextGroup(true);
      
      if (prev != null)
      {
         prev.setNextGroupItem(this);
         fic.setTextGroupPrev(prev.getId());
      }
   }

   /**
    * Link widget with the next widget in the text group.
    * 
    * @param   next
    *          Reference to next widget in group.
    */
   public void setNextGroupItem(FillInWidget next)
   {
      if (next != null)
         fic.setTextGroupNext(next.getId());
   }

   /**
    * Reset grouping flag and links to previous and next widget in the text
    * group.
    */
   public void resetGrouping()
   {
      fic.setTextGroup(false);
      fic.setTextGroupNext(-1);
      fic.setTextGroupPrev(-1);
   }

   /**
    * Set value of the NATIVE attribute.
    *
    * @param   nativ
    *          New value for the attribute.
    */
   public void setNative(boolean nativ)
   {
      fic.setNativ(nativ);
   }
}
