/*
** Module   : NullWidget.java
** Abstract :
**
** Copyright (c) 2008-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------Description-----------------
** 001 SIY 20080409  @37874  Created initial version which is intended to
**                           help avoid returning null from LogicalTerminal.
**                           getFocus() and let us fix some failing tests.
** 002 CA  20090227  @41385  Added WrappedResources.isUnknown method; this
**                           implementation returns true.
** 003 SIY 20101002          Minor javadoc cleanups.
** 004 ECF 20101006          Changed signature of getName to return character
**                           rather than String.
** 005 SIY 20111101          Updated imports.
** 006 CA  20130112          getNextSibling and getPrevSibling must return a
**                           handle instance.
** 007 CA  20130221          Refactored usage of TYPE and FORMAT attribute.
*/

package com.goldencode.p2j.ui;

import com.goldencode.p2j.persist.*;
import com.goldencode.p2j.util.*;

/**
 * Pseudo-widget which represents null-reference to GenericWidget.
 * 
 * @author  SIY
 * @version 1.0
 */
public class NullWidget
extends GenericWidget
{
   /**
    * Default constructor.
    */
   public NullWidget()
   {
      super(new ComponentConfig(ComponentConfig.UNKNOWN_TYPE, null));
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public decimal getColumn()
   {
      showError("COL");
      return new decimal(0);
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public integer getDcolor()
   {
      showError("DCOLOR");
      return new integer(0);
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public GenericWidget getFirstChild()
   {
      showError("FIRST-CHILD");
      return new NullWidget();
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public character getFormat()
   {
      showError("FORM");
      return new character("");
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public GenericFrame getFrame()
   {
      showError("FRAME");
      //TODO: Probably we should return something more safe than this.
      // Perhaps it worth to consider inherit NullWidget from GenericFrame.
      return null;
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public decimal getHeightChars()
   {
      showError("HEIGHT");
      return new decimal(0);
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public character getHelp()
   {
      showError("HELP");
      return new character("");
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public integer getInnerChars()
   {
      showError("INNER-CHARS");
      return new integer(0);
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public integer getInnerLines()
   {
      showError("INNER-LINES");
      return new integer(0);
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public character getLabel()
   {
      showError("LABEL");
      return new character("");
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public GenericWidget getLastChild()
   {
      showError("LAST-CHILD");
      return new NullWidget();
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public character getListItemPairs()
   {
      showError("LIST-ITEM-PAIRS");
      return new character("");
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public character getListItems()
   {
      showError("LIST-ITEMS");
      return new character("");
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public decimal getMaxHeightChars()
   {
      showError("MAX-HEIGHT");
      return new decimal(0);
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public decimal getMaxWidthChars()
   {
      showError("MAX-WIDTH");
      return new decimal(0);
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public character getName()
   {
      showError("NAME");
      return new character("");
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public handle getNextSibling()
   {
      showError("NEXT-SIBLING");
      return new handle(new NullWidget());
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public GenericWidget getNextTabItem()
   {
      showError("NEXT-TAB-ITEM");
      return new NullWidget();
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public integer getNumColumns()
   {
      showError("NUM-COLUMNS");
      return new integer(0);
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public integer getNumSelectedRows()
   {
      showError("NUM-SELECTED-ROWS");
      return new integer(0);
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public Object getParent()
   {
      showError("PARENT");
      return new NullWidget();
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public integer getPfColor()
   {
      showError("PFCOLOR");
      return new integer(0);
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public handle getPrevSibling()
   {
      showError("PREV-SIBLING");
      return new handle(new NullWidget());
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public character getPrivateData()
   {
      showError("PRIVATE-DATA");
      return new character("");
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public P2JQuery getQuery()
   {
      showError("QUERY");
      // TODO: this is just a placeholder, we need something other here.
      return new QueryWrapper(false);
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public decimal getRow()
   {
      showError("ROW");
      return new decimal(0);
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public character getScreenValue()
   {
      showError("SCREEN-VALUE");
      return new character("");
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public character getTitle()
   {
      showError("TITLE");
      return new character("");
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public character getResourceType()
   {
      showError("TYPE");
      return new character("");
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public integer getX()
   {
      showError("X");
      return new integer(0);
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public integer getY()
   {
      showError("Y");
      return new integer(0);
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public logical isHidden()
   {
      showError("HIDDEN");
      return new logical(false);
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public logical isKeepFrameZOrder()
   {
      showError("KEEP-FRAME-Z-ORDER");
      return new logical(false);
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public logical isMultiple()
   {
      showError("MULTIPLE");
      return new logical(false);
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public logical isReadOnly()
   {
      showError("READ-ONLY");
      return new logical(false);
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public logical isScrollable()
   {
      showError("SCROLLABLE");
      return new logical(false);
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public logical isSelected()
   {
      showError("SELECTED");
      return new logical(false);
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public logical isSensitive()
   {
      showError("SENSITIVE");
      return new logical(false);
   }

   /**
    * Stub method any call to which produces error message.
    */
   @Override
   public logical isVisible()
   {
      showError("VISIBLE");
      return new logical(false);
   }

   /**
    * Reports if this object is unknown.<p>
    * This implementation always returns <code>true</code>.
    *
    * @return   <code>true</code>.
    */
   @Override
   public boolean isUnknown()
   {
      return true;
   }
   
   /**
    * Common error routine.
    * 
    * @param   attribute
    *          Attribute name.
    *          
    * @throws ErrorConditionException 
    */
   private void showError(String attribute)
   throws ErrorConditionException
   {
      StringBuilder buf = new StringBuilder(100);
      buf.append("Cannot access the ");
      buf.append(attribute);
      buf.append(" attribute because the widget does not exist. (3140)");

      // TODO: Here we should terminate current statement, but there is no way
      // to do this. Also, displayed message somehow affects the pausing in
      // message statements, so they behave slightly different (message is
      // always displayed alone, other messages are cleared.
      if (!ErrorManager.isSilentError())
         ErrorManager.displayError(buf.toString());
   }
}
