/*
** Module   : CommonHandle.java
** Abstract : Defines common APIs used by all handles.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 CA  20130112 Created initial version.
** 002 CA  20130221 Renamed getType to getResourceType to avoid colisions with Resolvable.getType. 
*/

package com.goldencode.p2j.util;

/**
 * Exposes the following methods or attributes, common for all handles:
 * <table>
 * <tr>
 *    <th>attribute or method</th>
 *    <th>API</th>
 * </tr>
 * <tr>
 *    <td>TYPE</td>
 *    <td>{@link #getResourceType()}</td>
 * </tr>
 * </table>
 * The {@link #readOnlyError(String)} API is emitted only in cases when the
 * conversion rules decide that the given attribute is used on the right side
 * of an assignment, but that attribute is read-only. 
 */
public interface CommonHandle
extends WrappedResource
{
   /**
    * Get the type of this handle.
    * 
    * @return   See above.
    */
   public character getResourceType();
   
   /**
    * Show a specific error, as this read-only <code>attribute</code> was used
    * on the right-side of an assignment.
    *  
    * @param    attribute
    *           The read-only attribute.
    */
   public void readOnlyError(String attribute);
}
