/*
** Module   : PersistentProcedure.java
** Abstract : Defines common APIs used by the PROCEDURE handle.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 CA  20130112 Created initial version.
** 002 CA  20130221 Added ADM-DATa and UNIQUE-ID support.
*/

package com.goldencode.p2j.util;

import com.goldencode.p2j.ui.*;

/**
 * Exposes the following methods or attributes, common for PROCEDURE handles:
 * <table>
 * <tr>
 *    <th>attribute or method</th>
 *    <th>API</th>
 * </tr>
 * <tr>
 *    <td>INTERNAL-ENTRIES</td>
 *    <td>{@link #internalEntries()}</td>
 * </tr>
 * <tr>
 *    <td>PERSISTENT</td>
 *    <td>{@link #isPersistent()}</td>
 * </tr>
 * <tr>
 *    <td>CURRENT-WINDOW</td>
 *    <td>{@link #currentWindow()} and 
 *        {@link #setProcCurrentWindow(WindowWidget)}
 *    </td>
 * </tr>
 * <tr>
 *    <td>GET-SIGNATURE()</td>
 *    <td>{@link #getSignature(character)} and {@link #getSignature(String)}
 *    </td>
 * </tr>
 * <tr>
 *    <td></td>
 *    <td></td>
 * </tr>
 * <tr>
 *    <td></td>
 *    <td></td>
 * </tr>
 * <tr>
 *    <td></td>
 *    <td></td>
 * </tr>
 * <tr>
 *    <td></td>
 *    <td></td>
 * </tr>
 * </table>
 * This interface is used as a returned type by the 
 * {@link handle#unwrapProcedure(handle)} API, which, depending on the 
 * handle's state and type, it either returns an 
 * {@link ExternalProgramWrapper} instance, or a dynamic proxy using 
 * {@link handle#invalidAttrAccessProxy}. 
 */
public interface PersistentProcedure
extends CommonHandleChain,
        CommonProcedure,
        CommonFile,
        ADMData,
        UniqueID
{
   /**
    * Get the <code>internal-entries</code> attribute of this 
    * {@link TransparentWrapper#referent external procedure instance.}
    * 
    * @return   See above.
    */
   public character internalEntries();

   /**
    * Get the <code>persistent</code> attribute of this 
    * {@link TransparentWrapper#referent external procedure instance.}
    * 
    * @return   See above.
    */
   public logical isPersistent();

   /**
    * Execute the <code>get-signature</code> method of this 
    * {@link TransparentWrapper#referent external procedure instance.}
    * 
    * @param    internalEntry
    *           The legacy name of the internal-entry for which the signature
    *           is needed. 
    */
   public character getSignature(String internalEntry);

   /**
    * Execute the <code>get-signature</code> method of this 
    * {@link TransparentWrapper#referent external procedure instance.}
    * 
    * @param    internalEntry
    *           The legacy name of the internal-entry for which the signature
    *           is needed. 
    */
   public character getSignature(character internalEntry);
   
   /**
    * Get CURRENT-WINDOW attribute for this procedure handle.
    * 
    * @return  Reference to current window widget.
    */
   public WindowWidget currentWindow();

   /**
    * Set CURRENT-WINDOW for this procedure handle.
    * 
    * @param   cWin
    *          Window reference.
    */
   public void setProcCurrentWindow(WindowWidget cWin);
}