/*
** Module   : XNodeRef
** Abstract : DOM XML Node reference resource type interface.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 EVL 20130130 Created initial version.
** 002 CA  20130221 Added LOCAL-NAME support. 
*/

package com.goldencode.p2j.xml;

import com.goldencode.p2j.util.*;

/**
 * Interface describinf X-Node-Reference specific features of the DOM XML
 * objects.
 */
public interface XNodeRef
extends XEntity,
        LocalName
{
   // Attributes
   /**
    * Getting the attribute names available for curreny node reference.
    * 
    * @return   The comma separated character string of all available
    *           attributed.
    */
   public character getAttributeNames();
   
   /**
    * Getting the Docunment the current reference belongs to.
    * 
    * @return   The handle of the Document containing tne curreny reference..
    */
   public handle getOwnerDocument();
   
   // Methods
   /**
    * Deleting the internals of the current X-Node-Reference.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical deleteNode();
   
   /**
    * Getting the attribute value for a given attribute name.
    * 
    * @param    name
    *           The name of the attribute to return.
    *
    * @return   The comma separated character string of all available
    *           attributed.
    */
   public character getAttribute(String name);
   
   /**
    * Getting the attribute value for a given attribute name.
    * 
    * @param    name
    *           The name of the attribute to return.
    *
    * @return   The comma separated character string of all available
    *           attributed.
    */
   public character getAttribute(character name);
   
   /**
    * Setting the attribute value for a given attribute name.
    * 
    * @param    name
    *           The name of the attribute to change.
    * @param    value
    *           The new value for the given attribute name.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical setAttribute(String name, String value);

   /**
    * Setting the attribute value for a given attribute name.
    * 
    * @param    name
    *           The name of the attribute to change.
    * @param    value
    *           The new value for the given attribute name.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical setAttribute(String name, character value);

   /**
    * Setting the attribute value for a given attribute name.
    * 
    * @param    name
    *           The name of the attribute to change.
    * @param    value
    *           The new value for the given attribute name.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical setAttribute(character name, String value);

   /**
    * Setting the attribute value for a given attribute name.
    * 
    * @param    name
    *           The name of the attribute to change.
    * @param    value
    *           The new value for the given attribute name.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical setAttribute(character name, character value);
}
